@@ -159,6 +159,13 @@ proc qrouter::standard_route {{filename ""} {doquit true}} {
 	    }
 	}
     }
+    cleanup all
+    if {$result == 0} {
+	if {![catch {antenna init}]} {
+	    puts stdout "*** Running antenna violation checks"
+	    antenna fix
+	}
+    }
     if {${rootname} != ""} {
         puts stdout "*** Writing DEF file $deffilename"
 	write_def $deffilename
@@ -166,7 +173,6 @@ proc qrouter::standard_route {{filename ""} {doquit true}} {
         puts stdout "*** Writing DEF file (default)"
 	write_def
     }
-
     if {$result > 0} {
 	write_failed fail.out
     }
@@ -220,6 +226,9 @@ proc qrouter::congestion_route {filename} {
       qrouter::write_congested $filename
    }
    write_def
+   if {$result > 0} {
+      write_failed fail.out
+   }
    quit
 }
 
@@ -253,7 +262,7 @@ proc qrouter::lowerconsole {} {
     consoledown
 }
 
-puts stdout "Qrouter detail maze router version 1.3.109.T"
+puts stdout "Qrouter detail maze router version 1.4.50.T"
 
 set autoquit 0
 set autoroute 0
